"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const path_1 = __importDefault(require("path"));
const fs_1 = __importDefault(require("fs"));
/**
 * Checks if an addon has non-empty `app` or `addon` trees to determine if it
 * is a "runtime addon", and thus worth tracking.
 *
 * Note that dot-files (e.g. `.gitignore`) will be ignored when scanning files
 * in these directories.
 */
function isRuntimeAddon(addon) {
    for (const treeName of ['app', 'addon']) {
        const treePath = path_1.default.join(addon.root, (addon.treePaths && addon.treePaths[treeName]) || treeName);
        if (isPathUsed(treePath)) {
            return true;
        }
    }
    return false;
}
exports.default = isRuntimeAddon;
function isPathUsed(path) {
    if (fs_1.default.existsSync(path)) {
        let files = fs_1.default.readdirSync(path);
        for (let file of files) {
            if (file.indexOf('.') !== 0) {
                return true;
            }
        }
    }
    return false;
}
//# sourceMappingURL=is-runtime-addon.js.map